#!/bin/bash
#

# build_pyfits.sh 

usage()
{
   echo "USAGE: `basename ${0}` <product_directory> <e4:prof|e5:prof> [tar]"
}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

function die()
{
  echo "$1"; exit 2
}

get_this_dir() 
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`
    
    setup ssibuildshims ${ssibuildshims_version} -z ${product_dir}
    if [ -z ${SSIBUILDSHIMS_DIR} ]
    then
       echo "ERROR: failed to setup ssibuildshims ${ssibuildshims_version}"
       exit 1
    fi
}

set_qualifiers()
{
    if [ -z ${basequal} ]
    then
        echo "ERROR: please specify the qualifiers"
        usage
        exit 1
    fi

    fullqual=${basequal}
    qualdir=`echo ${basequal} | sed -e 's/:/-/g'`
    qualver=`echo ${basequal} | sed -e 's/:/_/g'`
}

get_platform_name()
{
    OS1=`uname`
    flvr=`ups flavor`
    if [ ${OS1} = "Darwin" ]
    then
	flvr=`ups flavor -2`
    fi
    OS=`${SSIBUILDSHIMS_DIR}/bin/get_os_platform`
    plat=`${SSIBUILDSHIMS_DIR}/bin/get_os_platform osplat`

    if [ -z ${flvr} ]
    then
       echo "ERROR: could not determine flavor for this platform"
       echo "       something is very wrong"
       exit 1
    fi

    pkgdir=${product_dir}/${package}/${pkgver}/${flvr}-${qualdir}
    tardir=${product_dir}/${package}/${pkgver}/tar
    patchdir=${product_dir}/${package}/${pkgver}/patch
    sourcedir=${product_dir}/${package}/${pkgver}/source
    blddir=${product_dir}/${package}/${pkgver}/build/${flvr}
}

function die()
{
  echo "$1"; exit 2
}

# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

product_dir=${1}
basequal=${2}
maketar=${3}

if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the local product directory"
   usage
   exit 1
fi

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=pyfits
origpkgver=v3_2
pkgver=${origpkgver}a
ssibuildshims_version=v0_08_00
pkgdotver=`echo ${origpkgver} | sed -e 's/_/./g' | sed -e 's/^v//'`
pkgtarname=${package}-${pkgdotver}

get_this_dir
get_ssibuildshims
set_qualifiers
get_platform_name


if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} ${fullqual}
   exit 0
fi

echo "building ${package} for ${OS}-${plat}-${qualdir} (flavor ${flvr})"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

# declare now so we can setup
# fake ups declare
fakedb=${product_dir}/${package}/${pkgver}/fakedb
${SSIBUILDSHIMS_DIR}/bin/fake_declare_product ${product_dir} ${package} ${pkgver} ${fullqual}

# setup
setup -B ${package} ${pkgver} -q ${fullqual} -z ${fakedb}:${product_dir}:${PRODUCTS} || die "ERROR: fake setup failed"

mkdir -p ${blddir} 
if [ ! -d ${blddir} ]
then
   echo "ERROR: failed to create ${blddir}"
   exit 1
fi

ncore=`${SSIBUILDSHIMS_DIR}/bin/ncores`

if [ ${OS1} = "Darwin" ]
then
   PATH=`dropit /usr/bin/get-cert $PATH`
fi

set -x

# work in a build directory, which will not be part of any distribution
cd ${blddir}
tar xf ${tardir}/${pkgtarname}.tar.gz || die "Failed to untar ${pkgtarname}.tar.gz"
cd ${package}-${pkgdotver} || die "Failed to cd into ${package}-${pkgdotver}"
python setup.py install --prefix ${pkgdir} --single-version-externally-managed --root "/"  || die "python setup.py install failed"

set +x

if [ ! -d ${pkgdir}/lib ]
then
   echo "ERROR: failed to create ${pkgdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi

#replace hardwired python path 
sed '1s/^.*$/#!\/usr\/bin\/env python /' ${pkgdir}/bin/fitsdiff > ${pkgdir}/bin/fitsdifftmp
mv ${pkgdir}/bin/fitsdifftmp ${pkgdir}/bin/fitsdiff 
chmod 755 ${pkgdir}/bin/fitsdiff 

sed '1s/^.*$/#!\/usr\/bin\/env python /' ${pkgdir}/bin/fitscheck > ${pkgdir}/bin/fitschecktmp
mv ${pkgdir}/bin/fitschecktmp ${pkgdir}/bin/fitscheck 
chmod 755 ${pkgdir}/bin/fitscheck 

# real ups declare
${SSIBUILDSHIMS_DIR}/bin/declare_product ${product_dir} ${package} ${pkgver} ${fullqual}

# -------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup ${package} ${pkgver} -q ${fullqual} -z ${product_dir}
echo "pyfits is installed at ${PYFITS_FQ_DIR}"

# this must be last
if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} ${fullqual}
fi

exit 0
